@@ -19,11 +19,15 @@ class CaseRunner(Protocol[CoCaseType, CaseArtifactType]):
         ...
 
 
+# for some reason, using a dataclass here was problematic.
 class Trickle:
     """This type is used to identify attributes marked with trickles()."""
 
+    def __init__(self, no_override: bool = False):
+        self.no_override = no_override
 
-def trickles() -> Any:
+
+def trickles(*, no_override: bool = False) -> Any:
     """Marks an attribute as one that can 'trickle down' from module scope
     into table cases as a default value."""
-    return Trickle()
+    return Trickle(no_override)
